---
name: 'Issue: Feature Request'
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

# Goal
A clear and concise description of what you want to happen.

# Motivation
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

# Considerations
A clear and concise description of any alternative solutions or features you've considered.

# Risks
A breakdown of the potential negative consequences or uncertainties that could accompany the implementation of this new feature.
